@@ -232,9 +232,17 @@ class GraphAPI(object):
         if type(data) is dict:
 
             if 'error' in data:
-                raise self.FacebookError(data['error']['message'], data['error']['code'])
+                error = data['error']
+
+                raise self.FacebookError(
+                    error.get('message'),
+                    error.get('code', None)
+                )
             if 'error_msg' in data:
-                raise self.FacebookError(data['error_msg'], data['error_code'])
+                raise self.FacebookError(
+                    data.get('error_msg'),
+                    data.get('error_code', None)
+                )
 
         return data
 
